@@ -59,6 +59,23 @@ def test_link():
     assert obj2.a == 1
 
 
+def test_link_holoviews_stream():
+    "Link a Reactive object to a HoloViews stream"
+    try:
+        import holoviews as hv
+    except ImportError:
+        pytest.skip("holoviews not available")
+
+    class ReactiveLink(Reactive):
+        selection = param.List(default=[])
+
+    obj = ReactiveLink()
+    stream = hv.streams.Selection1D()
+    obj.link(stream, selection='index')
+    obj.selection = [0, 1]
+    assert stream.index == [0, 1]
+
+
 def test_param_rename():
     "Test that Reactive renames params and properties"
 
@@ -448,16 +465,6 @@ def test_reactive_html_no_id_method_error():
                 pass
     assert "Found <div> node with the `onclick` callback referencing the `_onclick` method." in str(excinfo.value)
 
-def test_reactive_html_no_id_child_error():
-
-    with pytest.raises(ValueError) as excinfo:
-        class Test(ReactiveHTML):
-            child = param.Parameter()
-
-            _template = '<div>${child}</div>'
-
-    assert "Found template text referencing 'child' outside an element with an id." in str(excinfo.value)
-
 def test_reactive_html_dom_events():
 
     class TestDOMEvents(ReactiveHTML):
